@@ -275,7 +275,7 @@ class StatusCastAPIDriver:
     @GET
     def components_get(self,endpoint,method,data):
         """ Handler for components GET request; endpoint can be /components/<id> or /components """
-        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -287,7 +287,7 @@ class StatusCastAPIDriver:
         # Ensure presence of required data fields
         required_data = ["name","description","priority","parentId","isHidden"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
@@ -299,7 +299,7 @@ class StatusCastAPIDriver:
         Handler for components DELETE request; endpoint must be /components/<id>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
@@ -310,7 +310,7 @@ class StatusCastAPIDriver:
         """ Handler for components update request; endpoint must be /components?id=<id to update> """
         required_data = ["name","description","priority","parentId","isHidden"]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: {}".format(endpoint,','.join(required_data)))
@@ -354,7 +354,7 @@ class StatusCastAPIDriver:
                     "affectedComponents"
         ]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
@@ -365,7 +365,7 @@ class StatusCastAPIDriver:
         Handler for incidents DELETE request; endpoint must be /incidents/<id>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
@@ -390,7 +390,7 @@ class StatusCastAPIDriver:
                     "affectedComponents"
         ]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("PUT request to {} requires ?id=<id to update> at end of URL and data payload {}".format(endpoint,','.join(required_data)))
@@ -404,13 +404,13 @@ class StatusCastAPIDriver:
           """
         # Doesn't require parameters, so just execute request
         if "incidenttypes" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
             return r, json.loads(r.content)
         elif "?id=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
             return r, json.loads(r.content)
         elif "?start=" in endpoint and "end=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("Cannot perform GET request on endpoint {}".format(endpoint))
@@ -443,22 +443,22 @@ class StatusCastAPIDriver:
     def statuspage_router(self,endpoint,method,data):
         """ Router for /statuspage requests """
         if "addhit" in endpoint:
-            return self.statuspage_addhit(endpoint,method,data)
+            return self.statuspage_addhit("{}{}".format(self.base_url,endpoint),method,data)
         elif "css" in endpoint:
-            return self.statuspage_css(endpoint,method,data)
+            return self.statuspage_css("{}{}".format(self.base_url,endpoint),method,data)
         elif "calendarevents" in endpoint:
-            return self.statuspage_calendarevents(endpoint,method,data)
+            return self.statuspage_calendarevents("{}{}".format(self.base_url,endpoint),method,data)
         elif "dashboardposts" in endpoint:
-            return self.statuspage_dashboardposts(endpoint,method,data)
+            return self.statuspage_dashboardposts("{}{}".format(self.base_url,endpoint),method,data)
         elif "dashboardgrid" in endpoint:
-            return self.statuspage_dashboardgrid(endpoint,method,data)
+            return self.statuspage_dashboardgrid("{}{}".format(self.base_url,endpoint),method,data)
         elif "metrics" in endpoint:
-            return self.statuspage_metrics(endpoint,method,data)
+            return self.statuspage_metrics("{}{}".format(self.base_url,endpoint),method,data)
         elif "settings" in endpoint:
-            return self.statuspage_settings(endpoint,method,data)
+            return self.statuspage_settings("{}{}".format(self.base_url,endpoint),method,data)
         elif endpoint.endswith('statuspage') or endpoint.endswith('statuspage/'):
             # Valid get request, must be GET though. No data/payload.
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
+            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("Invalid endpoint given: {}".format(endpoint))
@@ -468,12 +468,12 @@ class StatusCastAPIDriver:
     def statuspage_addhit(self,endpoint,method,data):
         """ Handler for POST /statuspage/addhit request """
         # Rare: post request that does not require data; hits an endpoint, increments a counter on their end.
-        r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
         return r, r.content
     @GET
     def statuspage_css(self,endpoint,method,data):
         """ Handler for GET /statuspage/css request """
-        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
         return r, r.content # Not json; is a CSS string e.g. "body { background: white }"
 
     @GET
@@ -482,7 +482,7 @@ class StatusCastAPIDriver:
         Requires start and end date
         """
         if "?start=" in endpoint and "end=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?start=<start date>&end=<end date> in URL".format(endpoint))
@@ -493,7 +493,7 @@ class StatusCastAPIDriver:
         Requires date to receive posts for
          """
         if "?date=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?date=<date to receive posts> in URL".format(endpoint))
@@ -504,7 +504,7 @@ class StatusCastAPIDriver:
         Requires offset (number of days offset from current date)
         """
         if "?offset=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires data: ?offset=<number of days offset from current date> in URL".format(endpoint))
@@ -519,7 +519,7 @@ class StatusCastAPIDriver:
         metricId: id of metric to receive data for
         """
         if "type=" in endpoint and "period=" in endpoint and "metricId=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("GET request to {} requires data: ?type=<pingdom, newrelic or custom>&period=<Day,Week,Month>&metricId=<id of metric to get data for> in URL".format(endpoint))
@@ -527,7 +527,7 @@ class StatusCastAPIDriver:
     @GET
     def statuspage_settings(self, endpoint,method,data):
         """ Handler for GET /statuspage/settings """
-        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -540,9 +540,9 @@ class StatusCastAPIDriver:
         if m(method) == "delete":
             return self.subscribers_delete("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "post":
-            return self.subscribers_invite(endpoint,method,data)
+            return self.subscribers_invite("{}{}".format(self.base_url,endpoint),method,data)
         elif m(method) == "get":
-            return self.subscribers_list(endpoint,method,data)
+            return self.subscribers_list("{}{}".format(self.base_url,endpoint),method,data)
         else:
             print("{} is an invalid method for {}".format(method,endpoint))
             return None,None
@@ -553,7 +553,7 @@ class StatusCastAPIDriver:
         Handler for subscriber DELETE request; endpoint must be /components/<id to delete>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
@@ -571,7 +571,7 @@ class StatusCastAPIDriver:
          """
         required_data = ["emailAddress","createAccount","sendPassword","components"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
@@ -584,7 +584,7 @@ class StatusCastAPIDriver:
         currentPage		Number		page of results to return (defaults to 1)
         searchText		String		search by email address or full name
         """
-        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
 
@@ -593,7 +593,7 @@ class StatusCastAPIDriver:
         Router for /updates endpoint ; can create, delete or get details about update
         """
         if m(method) == "post":
-            return self.updates_create(endpoint,method,data)
+            return self.updates_create("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "delete":
             return self.updates_delete("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "get":
@@ -611,7 +611,7 @@ class StatusCastAPIDriver:
         """
         required_data = ["postId","datePosted","messageText","postType"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
@@ -623,7 +623,7 @@ class StatusCastAPIDriver:
         Handler for /updates DELETE request; endpoint must be /updates?=<id to delete>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
@@ -635,7 +635,7 @@ class StatusCastAPIDriver:
         Handler for /updates GET request; endpoint must be /updates?=<id to get details for>
         """
         if "?id=" in endpoint:
-            r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
             return r, json.loads(r.content)
         else:
             print("GET request to {} requires ?id=<id to get details for> at end of URL".format(endpoint))
@@ -649,9 +649,9 @@ class StatusCastAPIDriver:
         if m(method) == "get":
             return self.users_get("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "post":
-            return self.users_post(endpoint,method,data)
+            return self.users_post("{}{}".format(self.base_url,endpoint),method,data)
         if m(method) == "put":
-            return self.users_put(endpoint,method,data)
+            return self.users_put("{}{}".format(self.base_url,endpoint),method,data)
         else:
             print("{} is an invalid method for endpoint {}; only accepts delete,get,put,post".format(method,endpoint))
             return None,None
@@ -660,7 +660,7 @@ class StatusCastAPIDriver:
     def users_delete(self,endpoint,method,data):
         """ Handler for /users DELETE request , requires id as param """
         if "?id=" in endpoint:
-            r = self.auth_session.delete("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.delete(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("DELETE request to {} requires data: ?id=<id to delete> in URL".format(endpoint))
@@ -668,7 +668,7 @@ class StatusCastAPIDriver:
     @GET
     def users_get(self,endpoint,method,data):
         """ Handler for /users GET request; optional /:<id of user> """
-        r = self.auth_session.get("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+        r = self.auth_session.get(endpoint,data=data,verify=self.verify_ssl)
         return r, json.loads(r.content)
 
     @PUT
@@ -684,7 +684,7 @@ class StatusCastAPIDriver:
 
         required_data = ["userName","fullName","adminAccess"]
         if self.validate_data_keys(data,required_data) and "?id=" in endpoint:
-            r = self.auth_session.put("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.put(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("PUT request to {} requires ?id=<id of user to update> at end of URL and " + \
@@ -701,7 +701,7 @@ class StatusCastAPIDriver:
         """
         required_data = ["userName","fullName","adminAccess"]
         if self.validate_data_keys(data,required_data):
-            r = self.auth_session.post("{}{}".format(self.base_url,endpoint),data=data,verify=self.verify_ssl)
+            r = self.auth_session.post(endpoint,data=data,verify=self.verify_ssl)
             return r, r.content
         else:
             print("POST request to {} requires data: {}".format(endpoint,','.join(required_data)))
